#ifndef SYMFONIEABOUTDIALOG_H
#define SYMFONIEABOUTDIALOG_H

#include <QDialog>

namespace Ui {
    class SymfonieAboutDialog;
}

class SymfonieAboutDialog : public QDialog {
    Q_OBJECT
public:
    SymfonieAboutDialog(QWidget *parent = 0);
    ~SymfonieAboutDialog();


public Q_SLOTS:
    void openHomeUrlSlot();

protected:
    void changeEvent(QEvent *e);

private:
    Ui::SymfonieAboutDialog *ui;
};

#endif // SYMFONIEABOUTDIALOG_H
